#
# spec file for package sview
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define src_ver 17_04
%define src_name sView
%define ffmpeg_includedir %(pkg-config --variable=includedir libavcodec)
Name:           sview
Version:        17.04
Release:        pm151.2.13
Summary:        Stereoscopic media player
License:        GPL-3.0+ and LGPL-3.0+
Group:          Productivity/Multimedia/Video/Players
Url:            http://www.sview.ru/en/
Source:         https://github.com/gkv311/sview/archive/%{src_ver}.tar.gz#/%{name}-%{src_ver}.tar.gz
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libavcodec) = 57.107.100
BuildRequires:  pkgconfig(libavformat) = 57.83.100
BuildRequires:  pkgconfig(libavutil) = 55.78.100
BuildRequires:  pkgconfig(libconfig++)
BuildRequires:  pkgconfig(libswscale) = 4.8.100
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xrandr)
Requires:       xdg-utils
#Recommends:     mongoose
ExclusiveArch:  %{ix86} x86_64
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Stereoscopic Image Viewer and Movie Player.

%prep
%setup -q -n %{name}-%{src_ver}

dos2unix -k license-gpl* license-lgpl*

# Fix build for Factory
sed -i 's/xlocale\.h/locale.h/' $(grep -rwl xlocale)

%build
sed -e '/^INC/s|$|\ -I%{ffmpeg_includedir}|' \
    -e '/^CFLAGS/s/$/\ %{optflags}/' \
    -e '/^CXXFLAGS/s/$/\ %{optflags}/' \
    -i Makefile
# Remove %%_smp_mflags to avoid compilation errors
make -j1 EXTRA_LDFLAGS="-Wl,-rpath,%{_libdir}/%{src_name}"

%install
%make_install USR_LIB=%{_lib}

# GNOME switched to the freedesktop standard
rm -rf %{buildroot}%{_datadir}/application-registry
# Remove Debian directories
rm -rf %{buildroot}%{_datadir}/menu
# It's not necessary
rm -rf %{buildroot}%{_datadir}/icons/hicolor/*/apps/%{name}.png
# Use the installation in pixmaps
rm -rf %{buildroot}%{_datadir}/%{src_name}/icons/menu.xpm
install -Dm 0644 share/%{src_name}/icons/menu.xpm %{buildroot}%{_datadir}/pixmaps/%{name}.xpm
# Libraries used by the app must be placed into subdirectory
mv %{buildroot}%{_libdir}/*.so %{buildroot}%{_libdir}/%{src_name}

%fdupes -s %{buildroot}%{_datadir}

%suse_update_desktop_file -r %{src_name}IV Graphics Viewer
%suse_update_desktop_file -r %{src_name}MP AudioVideo Video Player

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc LICENSE*
%{_bindir}/%{src_name}
%{_libdir}/%{src_name}/
%{_datadir}/applications/%{src_name}IV.desktop
%{_datadir}/applications/%{src_name}MP.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%{_datadir}/pixmaps/%{name}.xpm
%{_datadir}/%{src_name}/

%changelog
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Fri Oct  6 2017 avvissu@yandex.by
- Update to 17.04:
  * update FFmpeg to 3.3, read panorama information from video files
  * fixed too long opening File Info dialog on some JPEG files with
    binary data present as metadata (coming from FFmpeg decoder)
- Drop 0001-Makefile-sort-input-files.patch (fixed)
* Sat Feb 11 2017 olaf@aepfle.de
- Sort wildcard lists with 0001-Makefile-sort-input-files.patch
* Wed Sep  7 2016 avvissu@yandex.by
- Update to 16.06:
  * update FFmpeg to 3.1.1
  * implement GPU-accelerated conversion of NV12 and XYZ12 formats
  * image Viewer - put original filename into save file dialog
  * fix saving playback time of recent file
  * fix tracking playback state for keeping screen on
  * improve language change without application restart
  * prevent creation of multiple modal dialogs
* Tue Dec  8 2015 avvissu@yandex.ru
- Fix build errors with ffmpeg: define ffmpeg_includedir
* Sun Nov 29 2015 avvissu@yandex.ru
- Update to 15.11:
  * introduces extended remote control from command line
  * adds support of sTER chunk in PNG files identifying
    side-by-side format
  * adds support of list of files within Drag & Drop. Two files are
    handled as stereo pair
  * updates experimental DXVA2 decoder - more codecs are now
    supported
  * fixes cursor hiding within NVIDIA 3D Vision output (Direct3D)
* Wed Oct 21 2015 avvissu@yandex.ru
- Update to 15.10:
  * adds support of cubemaps in format 3:2 (two rows per 3 quad
    sides)
  * adds button to activate 360 panorama view on toolbar
  * adds Czech translation files
  * adds option to automatically workaround aspect ratio of
    anamorphic 1080p and 720p videos
* Tue May 19 2015 avvissu@yandex.ru
- Initial package
